==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/wm_auth.js <==
/**
 * @brief: WebmailIqAuth handling class
 **/
function wm_auth(){
	this.xmlns='auth';
};

wm_auth.inherit(wm_generic);

var _me=wm_auth.prototype;

/*
param:
	auth_array[username]
	auth_array[password] or auth_array[digest]
*/
_me.login = function(auth_array,sDataSet,sDataPath){
	if (!auth_array['username'] || (!auth_array['password'] && !auth_array['digest'])) return false;

	// encrypt password
	if (!auth_array.digest)
		auth_array.digest = this.digest(auth_array['username'],auth_array['password']);

	/* Logout prevous user from dataset */
	this.logout();

	/* prepare data for request */
	var request={"USERNAME":[{"VALUE":auth_array.username}],"DIGEST":[{"VALUE":auth_array.digest}],"METHOD":[{"VALUE":'RSA'}]};

	/* send data to server & set response handler */
	if(!sDataSet){
		var aData = this.create_iq(request,'','set');
		if (this.error) return false;
		aData = aData["IQ"][0]["ATTRIBUTES"]["SID"];
		dataSet.add('main',['sid'],aData);

		/**
		 * BIND ONCLOSE METHOD
		 *
		 * Note:
		 * MSIE call onbeforeunload event if you click on <a href="javascript:void(0)">
		 * this bahaviour is weirdly random :-/
		 **/
/*
	var me = this,winevn = {};
	window.document.onmousedown = function(e) {
		var e = e || window.event;

		if (e.button==0) return true;

		var elm = e.target || e.srcElement;
		if (typeof elm == "undefined" || elm.tagName != 'A') return true;

		winevn.href = elm.href;
		winevn.time = (new Date).getTime();
	};
	window.onbeforeunload = function(e) {
		var e = e || window.event;

		if (winevn.time+500>(new Date).getTime() && winevn.href.indexOf('javascript:')>-1)
			return;

		me.logout(true);
	};
	// END ONCLOSE METHOD
*/
		return aData;
	}
	else
		this.create_iq(request,[this,'response',['login',sDataSet,sDataPath]],'set');

	return true;
};


_me.logout = function(bIgnoreResponse){

	if (!dataSet.get("main",['sid'])) return true;

	//Login save state 0
	if (cookieManager.get('LoginState') == '0')
		cookieManager.set('LoginState','1');
	
	if (bIgnoreResponse) {
		this.create_iq(null,[this,'_void'],'set');
		return true;
	}
	else
		var aData = this.create_iq(null,'','set');

	if (aData["IQ"][0]["ATTRIBUTES"]["TYPE"]=='result'){
		dataSet.remove("main",['sid'],true);
		return true;
	}
	else
		return false;
};

_me._forgot = function(email,sBody){

	var aRequest = {"FORGOT":[{"VALUE":email}],
					"SUBJECT":[{"VALUE":getLang('FORGOT_PASS::SUBJECT')}],
					"MESSAGE":[{"VALUE":sBody?sBody:getLang('FORGOT_PASS::MESSAGE')}]};

	var aResponse = (this.create_iq(aRequest,'','set')).IQ[0];

	if (aResponse.ATTRIBUTES.TYPE == 'result'){
		var emails = [];
		for(var i in aResponse.QUERY[0].EMAIL)
			emails.push(aResponse.QUERY[0].EMAIL[i].VALUE);

		return emails;
	}
	else
		return false;
};

_me._void = function(){};

_me.digest = function(user,pass){
	// encrypt password
	var rsa = new RSAKey();
		rsa.setPublic(this.hashid({"username":user}), '10001');
	return rsa.encrypt(pass);
};

/**
 * @brief: retrieve HashID from server
 * @query: <iq><query xmlns="webmail:iq:auth"><username>admin</username><method>rsa</method></query></iq>
 **/
_me.hashid = function(auth_array)
{
	/* prepare data for request */
	var request={"USERNAME":[{"VALUE":auth_array['username']}],"METHOD":[{"VALUE":'RSA'}]};

	/* send data to server & get response */
	var response=this.create_iq(request);

	/* return HashId */
	return response["IQ"][0]["QUERY"][0]["HASHID"][0]["VALUE"];
};

_me.response=function(aData,sMethodName,sDataSet,sDataPath)
{
	if (sDataSet == 'main')
		sDataPath = ['sid'];
	else
		sDataPath = sDataPath || ['sid'];

	switch(sMethodName){
	case 'login':
		dataSet.add(sDataSet,sDataPath,aData['Array']["IQ"][0]["ATTRIBUTES"]["SID"]);
		break;
	case 'logout':
		dataSet.add(sDataSet,sDataPath,'');
	}
};

/////////////////////////
var auth = new wm_auth();

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/wm_auth.js <==
/**
 * @brief: WebmailIqAuth handling class
 **/
function wm_auth(){
	this.xmlns='auth';
};

wm_auth.inherit(wm_generic);

var _me=wm_auth.prototype;

/*
param:
	auth_array[username]
	auth_array[password] or auth_array[digest]
*/
_me.login = function(auth_array,sDataSet,sDataPath){
	if (!auth_array['username'] || (!auth_array['password'] && !auth_array['digest'])) return false;

	// encrypt password
	if (!auth_array.digest)
		auth_array.digest = this.digest(auth_array['username'],auth_array['password']);

	/* Logout prevous user from dataset */
	this.logout();

	/* prepare data for request */
	var request={"USERNAME":[{"VALUE":auth_array.username}],"DIGEST":[{"VALUE":auth_array.digest}],"METHOD":[{"VALUE":'RSA'}]};

	/* send data to server & set response handler */
	if(!sDataSet){
		var aData = this.create_iq(request,'','set');
		if (this.error) return false;
		aData = aData["IQ"][0]["ATTRIBUTES"]["SID"];
		dataSet.add('main',['sid'],aData);

		return aData;
	}
	else
		this.create_iq(request,[this,'response',['login',sDataSet,sDataPath]],'set');

	return true;
};


_me.logout = function(bIgnoreResponse){

	if (!dataSet.get("main",['sid'])) return true;

	//Login save state 3
	if (cookieManager.get('LoginState') == '3')
		cookieManager.set('LoginState','2');

	if (bIgnoreResponse) {
		this.create_iq(null,[this,'_void'],'set');
		return true;
	}
	else
		this.create_iq(null,'','set');

	dataSet.remove("main",['sid'],true);
	return true;
};

_me._forgot = function(email,csid,captcha){

	var aRequest = {"FORGOT" :[{"VALUE":email}],
					"CAPTCHA":[{'ATTRIBUTES':{'UID':csid},"VALUE":captcha}],
					"SUBJECT":[{"VALUE":GWOthers.getItem('FORGOT_SETTINGS','subject') || getLang('FORGOT_PASS::SUBJECT')}],
					"MESSAGE":[{"VALUE":GWOthers.getItem('FORGOT_SETTINGS','mail') || getLang('FORGOT_PASS::EMAIL')}]};

	var aResponse = (this.create_iq(aRequest,'','set')).IQ[0];

	if (aResponse.ATTRIBUTES.TYPE == 'result'){
		var emails = [];
		for(var i in aResponse.QUERY[0].EMAIL)
			emails.push(aResponse.QUERY[0].EMAIL[i].VALUE);

		return emails;
	}
	else
	if (aResponse.ATTRIBUTES.TYPE == 'error')
		return aResponse.ERROR[0].ATTRIBUTES.UID;
	else
		return false;
};

_me._void = function(){};

_me.digest = function(user,pass){
	// encrypt password
	var rsa = new RSAKey();
		rsa.setPublic(this.hashid({"username":user}), '10001');
	return rsa.encrypt(pass);
};

/**
 * @brief: retrieve HashID from server
 * @query: <iq><query xmlns="webmail:iq:auth"><username>admin</username><method>rsa</method></query></iq>
 **/
_me.hashid = function(auth_array)
{
	/* prepare data for request */
	var request={"USERNAME":[{"VALUE":auth_array['username']}],"METHOD":[{"VALUE":'RSA'}]};

	/* send data to server & get response */
	var response=this.create_iq(request);

	/* return HashId */
	return response["IQ"][0]["QUERY"][0]["HASHID"][0]["VALUE"];
};

_me.response=function(aData,sMethodName,sDataSet,sDataPath)
{
	if (sDataSet == 'main')
		sDataPath = ['sid'];
	else
		sDataPath = sDataPath || ['sid'];

	switch(sMethodName){
	case 'login':
		dataSet.add(sDataSet,sDataPath,aData['Array']["IQ"][0]["ATTRIBUTES"]["SID"]);
		break;
	case 'logout':
		dataSet.add(sDataSet,sDataPath,'');
	}
};

/////////////////////////
var auth = new wm_auth();
